@@ -74,9 +74,7 @@ finger_do (Netinfo * netinfo)
 	buffer =
 		gtk_text_view_get_buffer (GTK_TEXT_VIEW (netinfo->output));
 
-	gtk_text_buffer_get_start_iter (buffer, &start);
-	gtk_text_buffer_get_end_iter (buffer, &end);
-
+	gtk_text_buffer_get_bounds (buffer, &start, &end);
 	gtk_text_buffer_delete (buffer, &start, &end);
 
 	parent = gtk_widget_get_toplevel (netinfo->output);
@@ -171,8 +169,7 @@ finger_copy_to_clipboard (Netinfo * netinfo, gpointer user_data)
 
 	buffer =
 		gtk_text_view_get_buffer (GTK_TEXT_VIEW (netinfo->output));
-	gtk_text_buffer_get_start_iter (buffer, &start);
-	gtk_text_buffer_get_end_iter (buffer, &end);
+	gtk_text_buffer_get_bounds (buffer, &start, &end);
 	result = gtk_text_buffer_get_text (buffer, &start, &end, FALSE);
 
 	gtk_clipboard_set_text (gtk_clipboard_get (GDK_NONE), result, -1);
